@@ -1251,7 +1251,7 @@ class Sf:
         return mdapi_object
 
     def metadata_list(self, metadata_type: str = '', metadata_type_list: list[str] = []) -> list:
-        if len(metadata_type_list) == 0 and metadata_type == '':
+        if len(metadata_type_list) == 0 and metadata_type != '':
             query = self.sf.mdapi.ListMetadataQuery(type=metadata_type)
         elif len(metadata_type_list) > 3:
             raise Exception("You can only query up to 3 metadata types at a time")
